dhg.data
======================


Base Class 
------------------------------
.. autoclass:: dhg.data.BaseData
    :members:


Graph Datasets
--------------------------------

.. autosummary::
    :toctree: ../generated/
    :nosignatures:
    :template: dataset_template.rst

    dhg.data.Cora
    dhg.data.Pubmed
    dhg.data.Citeseer
    dhg.data.BlogCatalog
    dhg.data.Flickr
    dhg.data.Github
    dhg.data.Facebook


Bipartite Graph Datasets 
--------------------------------

.. autosummary::
    :toctree: ../generated/
    :nosignatures:
    :template: dataset_template.rst

    dhg.data.MovieLens1M
    dhg.data.AmazonBook
    dhg.data.Yelp2018
    dhg.data.Gowalla
    dhg.data.TencentBiGraph
    dhg.data.CoraBiGraph
    dhg.data.PubmedBiGraph
    dhg.data.CiteseerBiGraph


Hypergraph Datasets
-----------------------

.. autosummary::
    :toctree: ../generated/
    :nosignatures:
    :template: dataset_template.rst

    dhg.data.Cooking200
    dhg.data.CoauthorshipCora
    dhg.data.CoauthorshipDBLP
    dhg.data.CocitationCora
    dhg.data.CocitationCiteseer
    dhg.data.CocitationPubmed
    dhg.data.YelpRestaurant
    dhg.data.WalmartTrips
    dhg.data.HouseCommittees
    dhg.data.News20
    dhg.data.DBLP4k
    dhg.data.DBLP8k
    dhg.data.IMDB4k
    dhg.data.Recipe100k
    dhg.data.Recipe200k
    dhg.data.Yelp3k
    dhg.data.Tencent2k


**Welcome to contribute datasets!**

